netapp_ontap.models.software_validation API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.software_validation`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SoftwareValidationSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SoftwareValidation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `action GET POST PATCH`

    The action field of the software_validation.

  `issue GET POST PATCH`

    The issue field of the software_validation.

  `status GET`

    Status of the update check.

    Valid choices:

    - warning
    - error
  `update_check GET`

    Name of the update check.

    Example: nfs_mounts